Coverage report

File | function | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/atlus/__init__.py | (no function) | 4 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | get_title | 3 | 0 | 0 | 2 | 0 | 100%
src/atlus/atlus.py | us_replace | 1 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | mc_replace | 5 | 0 | 0 | 2 | 0 | 100%
src/atlus/atlus.py | ord_replace | 1 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | name_street_expand | 4 | 1 | 0 | 2 | 1 | 67%
src/atlus/atlus.py | direct_expand | 4 | 1 | 0 | 2 | 1 | 67%
src/atlus/atlus.py | cap_match | 1 | 1 | 0 | 0 | 0 | 0%
src/atlus/atlus.py | lower_match | 1 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | grid_match | 1 | 1 | 0 | 0 | 0 | 0%
src/atlus/atlus.py | abbrs | 9 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | remove_br_unicode | 2 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | clean_address | 3 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | help_join | 2 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | addr_street | 1 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | addr_housenumber | 1 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | _combine_consecutive_tuples | 12 | 1 | 0 | 10 | 2 | 77%
src/atlus/atlus.py | _manual_join | 19 | 1 | 0 | 12 | 6 | 77%
src/atlus/atlus.py | collapse_list | 3 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | split_unit | 14 | 0 | 0 | 9 | 2 | 91%
src/atlus/atlus.py | remove_prefix | 3 | 0 | 0 | 2 | 0 | 100%
src/atlus/atlus.py | get_address | 35 | 2 | 0 | 20 | 5 | 87%
src/atlus/atlus.py | get_phone | 4 | 0 | 0 | 2 | 0 | 100%
src/atlus/atlus.py | (no function) | 33 | 0 | 0 | 0 | 0 | 100%
src/atlus/objects.py | (no function) | 9 | 0 | 0 | 0 | 0 | 100%
src/atlus/resources.py | (no function) | 24 | 0 | 0 | 2 | 0 | 100%
Total |  | 199 | 8 | 0 | 65 | 17 | 90%

No items found using the specified filter.